Travis-CI status:

[![Build Status](https://travis-ci.org/saullocastro/tudaesasII.svg?branch=master)](https://travis-ci.org/saullocastro/tudaesasII)

Github Actions status:

[![Actions Status](https://github.com/saullocastro/tudaesasII/workflows/pytest/badge.svg)](https://github.com/saullocastro/tudaesasII/actions)

Coverage status:

[![Coverage Status](https://coveralls.io/repos/github/saullocastro/tudaesasII/badge.svg?branch=master)](https://coveralls.io/github/saullocastro/tudaesasII?branch=master)


TU Delft
Aerospace Engineering
Aerospace Structures and Computational Mechanics
Stability and Analysis of Structures II
Ae4-ASM-511

This Python module can be used by the students to assist them in the
assignments.

If you use any content of this repository, please cite it as:

Castro, S.G.P. Supporting code for Computational Mechanics Stability and Analysis of Structures II, Department of Aerospace Structures and Materials, Delft University of Technology, 2020. DOI: 10.5281/zenodo.2583004.

License
-------
Distrubuted in the 2-Clause BSD license (https://raw.github.com/saullocastro/tudaesasII/master/LICENSE).

Contact: S.G.P.Castro@tudelft.nl

